@@ -15,7 +15,7 @@ from dbt_autofix.refactor import (
     changeset_remove_duplicate_keys,
     changeset_remove_extra_tabs,
     changeset_remove_indentation_version,
-    changeset_replace_spaces_underscores_in_name_values,
+    changeset_replace_non_alpha_underscores_in_name_values,
     dict_to_yaml_str,
     rec_check_yaml_path,
     remove_unmatched_endings,
@@ -902,6 +902,20 @@ class TestDbtProjectYAMLPusPrefix:
         assert expected_data == new_yml
         assert len(refactor_logs) == 2
 
+    def test_check_project_custom_config_not_in_meta(self, temp_project_dir: Path, schema_specs: SchemaSpecs):
+        test_data = {"models": {"custom_config": "custom_value", "folder": {"custom_config": "custom_value", "materialized": "table"}}}
+        expected_data ={"models": {"+meta": {"custom_config": "custom_value"}, "folder": {"+meta": {"custom_config": "custom_value"}, "+materialized": "table"}}}
+
+        new_file = temp_project_dir / "models" / "folder" / "my_model.sql"
+        new_file.parent.mkdir(parents=True, exist_ok=True)
+        new_file.write_text("select 1 as id")
+
+        new_yml, refactor_logs = rec_check_yaml_path(
+            test_data, temp_project_dir, schema_specs.dbtproject_specs_per_node_type["models"]
+        )
+        assert expected_data == new_yml
+        assert len(refactor_logs) == 3
+
     def test_check_project_no_change(self, temp_project_dir: Path, schema_specs: SchemaSpecs):
         # Test that output_yaml produces valid YAML
 
@@ -1195,7 +1209,7 @@ models:
         assert "accepted_values" in accepted_values_test
         assert "config" in accepted_values_test["accepted_values"]
         assert accepted_values_test["accepted_values"]["config"]["where"] == "date_column > __3_days_ago__"
-        assert accepted_values_test["accepted_values"]["values"] == ["placed", "shipped", "completed", "returned"]
+        assert accepted_values_test["accepted_values"]["arguments"]["values"] == ["placed", "shipped", "completed", "returned"]
 
         # Check that appropriate logs were generated
         assert any("Field 'where' moved under config" in log for log in result.refactor_logs)
@@ -1230,9 +1244,14 @@ models:
         assert test_name in test
         assert "config" in test[test_name]
         assert test[test_name]["config"]["where"] == "1=1"
-        assert test[test_name]["expression"] == "sum(col_numeric_a)"
-        assert test[test_name]["compare_model"] == 'ref("other_model")'
-        assert test[test_name]["group_by"] == ["idx"]
+        
+        assert "expression" not in test[test_name]
+        assert "compare_model" not in test[test_name]
+        assert "group_by" not in test[test_name]
+      
+        assert test[test_name]["arguments"]["expression"] == "sum(col_numeric_a)"
+        assert test[test_name]["arguments"]["compare_model"] == 'ref("other_model")'
+        assert test[test_name]["arguments"]["group_by"] == ["idx"]
 
         # Check that appropriate logs were generated
         assert any("Field 'where' moved under config" in log for log in result.refactor_logs)
@@ -1347,7 +1366,7 @@ models:
         # Check third test (dict without config)
         accepted_values_test = column["tests"][2]
         assert "accepted_values" in accepted_values_test
-        assert accepted_values_test["accepted_values"]["values"] == ["active", "inactive"]
+        assert accepted_values_test["accepted_values"]["arguments"]["values"] == ["active", "inactive"]
         assert "config" not in accepted_values_test["accepted_values"]
 
         # Check that appropriate logs were generated
@@ -1458,7 +1477,7 @@ sources:
         assert "accepted_values" in accepted_values_test
         assert "config" in accepted_values_test["accepted_values"]
         assert accepted_values_test["accepted_values"]["config"]["where"] == "status is not null"
-        assert accepted_values_test["accepted_values"]["values"] == ["pending", "active", "completed"]
+        assert accepted_values_test["accepted_values"]["arguments"]["values"] == ["pending", "active", "completed"]
 
         # Check that appropriate logs were generated
         assert any("Field 'where' moved under config" in log for log in result.refactor_logs)
@@ -1866,7 +1885,7 @@ models:
 class TestReplaceSpacesUnderscoresInNameValues:
     """Tests for changeset_remove_duplicate_keys function"""
 
-    def test_changeset_replace_spaces_underscores_in_name_values(self, schema_specs: SchemaSpecs):
+    def test_changeset_replace_non_alpha_underscores_in_name_values(self, schema_specs: SchemaSpecs):
         """Test that YAML without duplicate keys is not modified"""
         input_yaml = """
 version: 2
@@ -1876,8 +1895,9 @@ models:
 
 exposures: 
   - name: exposure with spaces
+  - name: exposure_with)(*!#$&)# special chars
 """
-        result = changeset_replace_spaces_underscores_in_name_values(input_yaml, schema_specs)
+        result = changeset_replace_non_alpha_underscores_in_name_values(input_yaml, schema_specs)
         assert result.refactored
         refactored_dict = safe_load(result.refactored_yaml)
 
@@ -1889,3 +1909,6 @@ exposures:
 
         exposure_refactored = refactored_dict["exposures"][0]
         assert exposure_refactored["name"] == "exposure_with_spaces"
+
+        exposure_special_chars_refactored = refactored_dict["exposures"][1]
+        assert exposure_special_chars_refactored["name"] == "exposure_with_special_chars"
